@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 BEGIN {
-    our $VERSION = '0.03';
+    our $VERSION = '0.04';
 
     require XSLoader;
     XSLoader::load('Math::Int64', $VERSION);
@@ -202,17 +202,13 @@ are L<Math::BigInt>, L<Math::BigRat> and L<Math::Big>,
 L<Math::BigInt::BitVect>, L<Math::BigInt::Pari> and
 L<Math::BigInt::GMP>.
 
-=head1 AUTHOR
-
-Salvador FandiE<ntilde>o, E<lt>sfandino@yahoo.comE<gt>
-
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2007 by Salvador FandiE<ntilde>o
+Copyright E<copy> 2007, 2009 by Salvador FandiE<ntilde>o
+(sfandino@yahoo.com)
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
